@@ -17,13 +17,13 @@ if ! has_executable lsb_release ; then
         apt-get -y install lsb-release
         apt-get -y install libnss3-tools
     else
-        echo "Debain/Ubuntu required for installation"
+        echo "Ubuntu required for installation"
         exit 1
     fi
 fi
 
 OS_SPEC=$(lsb_release --id --short | tr "[:upper:]" "[:lower:]")-$(lsb_release --release --short | egrep -o [0-9]+ | sed -n 1p)-$(dpkg --print-architecture)
-KTCLIENT_VERSION="7.8.0"
+KTCLIENT_VERSION="7.9.0"
 INSTALLER_FILENAME=KeyTalkClient-${KTCLIENT_VERSION}-${OS_SPEC}.tgz
 if [ ! -f ${INSTALLER_FILENAME} ]; then
     echo "${INSTALLER_FILENAME} not found!" >&2
