@@ -310,12 +310,12 @@ class CertRetrievalApi(object):
         with open("./encrypted_challenge", 'wb') as f:
             f.write(encrypted_challenge)
         result = run_cmd_checked(
-            "openssl cms -decrypt -in ./encrypted_challenge -signer {} -inkey {} -inform DER -print".format(
+            "openssl cms -decrypt -in ./encrypted_challenge -signer {} -inkey {} -inform DER -outform DER -print".format(
                 signer, signer))
         os.remove("./encrypted_challenge")
         plain_encoded_challenge = result.stdout
         # challenge is encoded as <body-size>#<body>
-        sep_pos = result.stdout.find('#')
+        sep_pos = plain_encoded_challenge.find('#')
         if sep_pos == -1:
             raise Exception("Ill-formed challenge '{}'".format(plain_encoded_challenge))
         length = int(plain_encoded_challenge[0:sep_pos])
@@ -1453,7 +1453,7 @@ def request_cert_with_password_authentication(cert_format):
 
 
 def request_cert_from_csr_with_password_authentication():
-    service = "CUST_PASSWD_INTERNAL_TESTUI"
+    service = "CUST_PASSWD_INTERNAL"
     username = 'DemoUser'
     password = 'secret'
 
